function hh = makeBPF( fd, N )
% makeBPF - design simple bandpass filter
%
% usage:
%   hh = makeBPF( fd, N )
%
% inputs:
%   fd - center frequency of pass band (normalized by fs)
%   N  - number of filter coefficients
%
% output:
%   hh - vector of filter coefficients

% sample locations
nn = -(N-1)/2:1:(N-1)/2;

% impulse response
hh = 2/N*cos(2*pi*fd*nn);
